InBatchMiner

Struct InBatchMiner 

pub struct InBatchMiner { /* private fields */ }
In-batch negative mining utility

Implementations

Source

impl InBatchMiner

pub fn instance_of<V: NapiRaw>(env: Env, value: V) -> Result<bool>

Source

impl InBatchMiner

Source

impl InBatchMiner

pub fn new() -> Self

Create a new in-batch miner

pub fn include_positive() -> Self

Create without excluding positive

pub fn get_negatives( &self, anchor_idx: u32, positive_idx: u32, batch_size: u32, ) -> Vec<u32>

Get negative indices for a given anchor in a batch

Arguments
  • anchor_idx - Index of the anchor in the batch
  • positive_idx - Index of the positive in the batch
  • batch_size - Total batch size
Returns

Array of indices that can be used as negatives